@@ -2,7 +2,7 @@
 dynamic children mix-in for kivy container widgets
 ==================================================
 
-This ae portion is providing the mixin class :class:`DynamicChildrenBehavior` for to add children widgets dynamically
+this ae portion is providing the mixin class :class:`DynamicChildrenBehavior` to add children widgets dynamically
 and data-driven to your kivy container widgets (like DropDowns, Popups or any layout widgets).
 """
 from typing import Any, Callable, Dict, List
@@ -17,32 +17,32 @@ from ae.base import UNSET
 from ae.deep import deep_object, deep_replace                                               # type: ignore
 
 
-__version__ = '0.2.6'
+__version__ = '0.2.7'
 
 
 class DynamicChildrenBehavior:
     """ mixin class for the dynamic creation/refresh of child widgets from a data map.
 
-    At least one of the classes that is mixing in this class has to inherit from Widget (or EventDispatcher) to get the
+    at least one of the classes that is mixing in this class has to inherit from Widget (or EventDispatcher) to get the
     :attr:`~DynamicChildrenBehavior.child_data_maps` attribute correctly initialized and firing on change.
     """
     child_data_maps: List[Dict[str, Any]] = ListProperty()
-    """ list of child data dicts for to instantiate the children of the inheriting layout/widget.
+    """ list of child data dicts to instantiate the children of the inheriting layout/widget.
 
-    Each child data dict is defining its own widget with the following keys:
+    each child data dict is defining its own widget with the following keys:
 
     * `cls`: either the class name or the class/type object of the widget to be created dynamically.
     * `kwargs`: dict of keyword arguments that will be passed to the constructor method of the widget.
-      All values in this dict with the magic string `'replace_with_data_map_container'` will be
+      all values in this dict with the magic string `'replace_with_data_map_container'` will be
       replaced with the instance of the container before it gets passed to the `__init__` method
       of the child (see :func:`~ae.deep.deep_replace`).
     * `attributes`: dict of attributes where the key is specifying the attribute name/path and the
       value the finally assigned attribute value.
-      The attribute name (the key of this dict) can be a deep/combined attribute/index path
+      the attribute name (the key of this dict) can be a deep/combined attribute/index path
       which allows to update deeper objects within the child object (via :func:`~ae.deep.deep_object`).
-      All values in this dict with the magic string `'replace_with_data_map_container'` will be
+      all values in this dict with the magic string `'replace_with_data_map_container'` will be
       replaced with the instance of the container before the child attributes get updated.
-      All values in this dict with the magic string `'replace_with_data_map_child'` will be
+      all values in this dict with the magic string `'replace_with_data_map_child'` will be
       replaced with the instance of the child before they get applied to it (via :func:`~ae.deep.deep_replace`).
 
     :attr:`child_data_maps` is a :class:`~kivy.properties.ListProperty` and
